##  Assign Application Owners
You can assign application owners using the following methods:
  * [Use surveys](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD#loioa339f8d4f3fe432c92ad432df5bbe550__use-surveys) (recommended): Send surveys to identify and assign application owners simultaneously.
  * [Use subscriptions](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD#loioa339f8d4f3fe432c92ad432df5bbe550__use-subscriptions): If you know which users to assign as application owners, use fact sheet subscriptions.
